@@ -1,6 +1,9 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
+#![allow(clippy::missing_safety_doc)]
+#![allow(clippy::non_send_fields_in_send_ty)]
+#![doc = include_str!("../README.md")]
 
 pub use ffi;
 pub use glib;
@@ -19,6 +22,7 @@ macro_rules! assert_initialized_main_thread {
 #[allow(clippy::match_same_arms)]
 #[allow(clippy::type_complexity)]
 #[allow(clippy::use_self)]
+#[allow(unused_imports)]
 mod auto;
 pub use crate::auto::*;
 
@@ -32,6 +36,4 @@ pub use crate::harness::Harness;
 pub mod prelude {
     #[doc(hidden)]
     pub use gst::prelude::*;
-
-    pub use crate::auto::traits::*;
 }
